@@ -1,11 +1,15 @@
-__version__ = "3.10.0"
+__version__ = "4.18.0"
 
 from ntropy_sdk.ntropy_sdk import (
+    AccountHolder,
     Transaction,
     SDK,
     Batch,
+    Model,
     NtropyError,
     NtropyBatchError,
     EnrichedTransaction,
     EnrichedTransactionList,
+    LabeledTransaction,
+    Report,
 )
